@@ -44,7 +44,7 @@ c				Declination of star (radians)
 	Real*8 DC(3),DCC(3),DPREMA(3,3),DVELH(3),DVELB(3)
 	Real*8 DPI,DAUKM,DCTROP,DCBES,DC1900,DCT0,DTR,DST
 	Real*8 DEQT,DRA2,DEC2,DHA,DARG
-	Integer*4 K
+	Integer K
 	Data DPI/3.1415926535897932d0/, DAUKM/1.4959787d08/,
      1	     DCTROP/365.24219572d0/, DCBES/0.313d0/, DC1900/1900.0d0/
      2	     DCT0/2415020.0d0/
@@ -378,7 +378,7 @@ c				Heliocentric velocity correction (returned)
 	Real*8 DVELB(3)
 c				Barycentric velocity correction (returned)
 
-	Integer*4 K, N
+	Integer K, N
 	Real*8 DCFEL(3,8),DCEPS(3),DCARGS(2,15)
 	Real*8 DCARGM(2,3), E, G
 	Real*8 CC2PI,CCSEC3,CCKM,CCMLD,CCFDI,T,TSQ,A
@@ -395,7 +395,7 @@ c				Barycentric velocity correction (returned)
      2			SINLM,COSLM,SIGMA,IDEQ
 	Real*8 DPREMA,DPSI,D1PDRO,DSINLS,DCOSLS,DSINEP,DCOSEP
 	Real*8 FORBEL,SORBEL,SINLP,COSLP,SINLM,COSLM,SIGMA
-	Integer*4 IDEQ
+	Integer IDEQ
 
 	Equivalence (SORBEL(1),E),(FORBEL(1),G)
 
