@@ -1,9 +1,9 @@
 # File lib/rvsao.h
-# May 27, 2020
+# March 15, 2022
 
-# RVSAO 2.8.4 header file
+# RVSAO 2.8.5 header file
 
-define	VERSION		"2.8.4"
+define	VERSION		"2.8.5"
 define	C		2.9979e5
 define	LN2		0.69314718
 define	CLN10		6.90292e5
@@ -173,3 +173,5 @@ define  COR_YES         5       # Cross-correlate velocity shift
 # Jun 27 2016	2.8.4: Add two digits to height in XVSAO report mode 13
 
 # May 27 2020	2.8.4: Pass spectrum and specim through new rvspec.com labelled common
+
+# Feb 14 2022	2.8.5: Update for IRAF 2.17
